==> dl.php?src=linea21_2_3_0.zip: linea21/languages/fr/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "publications";


/*	nommage des modules
 *  	*/
$lang['publication']['name']='publication';
$lang['publication']['name2']='publication(s)';
$lang['publication']['confirm_add'] = "Ajout de la publication réalisé avec succès\n";
$lang['publication']['confirm_mod'] = "Modification de la publication réalisée avec succès\n";
$lang['publication']['confirm_sup'] ="Suppression de la publication réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Ajout d\'une '.$lang['publication']['name'];
$lang['publication']['mod']= 'Modification d\'une '.$lang['publication']['name'];
$lang['publication']['sup']= 'Suppression de la '.$lang['publication']['name'];
$lang['publication']['det']= 'Détails de la '.$lang['publication']['name'];
$lang['publication']['list']= 'Consultation des publications';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Voir la partie suivante ';
$lang['publication']['prev_part']='Voir la partie précédente ';
$lang['publication']['goto']='Aller à ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Saisie des informations de la nouvelle '.$lang['publication']['name'];
$lang['publication']['mod_title']='Modification des informations de la '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Dressant des états des lieux, fixant les enjeux et engageant des réflexions sur des cas concrets, les publications sauront parfaire vos connaissances en matière de développement durable.';

/*	check integrité des données
 *  	*/
$lang['publication']['no_title'] = 'Il est nécessaire de donner un titre à la nouvelle publication';
$lang['publication']['no_resume'] = 'Il est nécessaire d\'établir un resumé de la publication';
$lang['publication']['no_level'] = 'La publication doit être rattachée à un niveau';
$lang['publication']['no_scale'] = 'La publication doit être rattachée à une échelle';
$lang['publication']['no_author'] = 'Il est impératif de nommer un rédacteur de publication';
$lang['publication']['author_not_valid'] = 'Le rédacteur choisi n\'existe pas ou son orthographe est erronée';
$lang['publication']['author_not_rights'] = 'Le rédacteur choisi n\'a pas les droits nécessaires';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='titre';
$lang['publication']['resume']='resumé';
$lang['publication']['level']='niveau de rattachement';
$lang['publication']['scale']='échelle de rattachement';
$lang['publication']['statut']='état de publication';
$lang['publication']['comment']='commentaire';

$lang['publication']['template']='modèle de présentation';
$lang['publication']['photouri']='visuel(s) associé(s)';
$lang['publication']['visu1']='visuel n°1';
$lang['publication']['visu2']='visuel n°2';
$lang['publication']['author']='rédacteur';
$lang['publication']['published_on']='date de publication';
$lang['publication']['not_published']='non publié';

$lang['publication']['generals']='Informations générales';
$lang['publication']['parts']='Détail de la publication';
$lang['publication']['listing']='Publications';
$lang['publication']['link_res']='Liens associés';
$lang['publication']['biblio_res']='Ressources bibliographiques';
$lang['publication']['multi_res']='Ressources Multimédia';
$lang['publication']['summary']='Sommaire';



/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' derniers ajouts effectués';
$lang['publication']['qb_titlemod']=' dernières modifications effectuées';
$lang['publication']['qb_titlesup']=' dernières suppressions effectuées';
$lang['publication']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/

$lang['publication']['nb_total']='publications sont repertoriées dans la base de données.';
$lang['publication']['statut_filter']='Afficher par statut';
$lang['publication']['part_number']='partie ';
$lang['publication']['part_number2']='Partie ';
$lang['publication']['description']='description';
$lang['publication']['all']='Afficher la liste complete';
$lang['publication']['noresult']='Aucune publication ne correspond à ce critère de sélection ';
$lang['news']['template_1']='Texte + photo à gauche';
$lang['news']['template_2']='Texte + photo à droite';
$lang['news']['template_3']='Texte seulement';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Ajouter une nouvelle partie";
$lang['publication']['add_new_linkres']="Associer un nouveau lien";
$lang['publication']['add_new_multires']="Associer un nouveau document numérique";
$lang['publication']['add_new_bibliores']="Associer un nouvelle référence bibliographique";

$lang['publication']['no_link']="Aucun site n'est actuellement associé";
$lang['publication']['del_link']="Supprimer le lien";
$lang['publication']['mod_link']="Modifier le lien";

$lang['publication']['no_multi']="Aucun document multimédia n'est actuellement associé";
$lang['publication']['del_multi']="Supprimer le document numérique";
$lang['publication']['mod_multi']="Modifier le document numérique";

$lang['publication']['no_biblio']="Aucune référence bibliographique n'est actuellement associée";
$lang['publication']['del_biblio']="Supprimer la référence bibliographique";
$lang['publication']['mod_biblio']="Modifier la référence bibliographique";

$lang['publication']['no_part']="Aucune partie n'est actuellement associée";
$lang['publication']['del_part']="Supprimer la partie";
$lang['publication']['mod_part']="Modifier la partie";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Pour ajouter une publication, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['publication']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['publication']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';

$lang['publication']['help_list1']='Pour afficher le détail d\'une publication, cliquez sur le titre de celui-ci';
$lang['publication']['help_list2']='Vous pouvez supprimer une publication en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_list3']='Vous pouvez modifier une publication en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les publications desirées';
$lang['publication']['help_list5']='Pour ajouter une publication, cliquez sur le lien \'ajouter une publlication\' dans la barre de titre';


$lang['publication']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['publication']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['publication']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['publication']['help_det1']='Vous pouvez modifier les informations générales de cette publication en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_det2']='Vous pouvez supprimer cette publication en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_det3']='Pour afficher les parties constituant la publication, les liens associés, documents multimédias et ressources bibliographiques, cliquer sur afficher ces informations en bas de page';
$lang['publication']['help_det4']='Pour Ajouter-Modifier-Supprimer les parties constituant la publication, les liens associés, documents multimédias et ressources bibliographiques, cliquer sur les icônes qui leur sont associées';

$lang['publication']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de cette publication, cliquer sur \'Annuler\'';


?>

==> dl.php?src=linea21_2_8_0.zip: linea21/languages/fr/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "publications";


/*	nommage des modules
 *  	*/
$lang['publication']['name']='publication';
$lang['publication']['name2']='publication(s)';
$lang['publication']['confirm_add'] = "Ajout de la publication réalisé avec succès\n";
$lang['publication']['confirm_mod'] = "Modification de la publication réalisée avec succès\n";
$lang['publication']['confirm_sup'] ="Suppression de la publication réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['publication']['add']= 'Ajout d\'une '.$lang['publication']['name'];
$lang['publication']['mod']= 'Modification d\'une '.$lang['publication']['name'];
$lang['publication']['sup']= 'Suppression de la '.$lang['publication']['name'];
$lang['publication']['det']= 'Détails de la '.$lang['publication']['name'];
$lang['publication']['list']= 'Consultation des publications';


/*	nommage public
 *  	*/
$lang['publication']['next_part']='Voir la partie suivante ';
$lang['publication']['prev_part']='Voir la partie précédente ';
$lang['publication']['goto']='Aller à ';
/*	nommage rubrique add / mod /det
 *  	*/
$lang['publication']['add_title']='Saisie des informations de la nouvelle '.$lang['publication']['name'];
$lang['publication']['mod_title']='Modification des informations de la '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Dressant des états des lieux, fixant les enjeux et engageant des réflexions sur des cas concrets, les publications sauront parfaire vos connaissances en matière de développement durable.';

/*	check integrité des données
 *  	*/
$lang['publication']['no_title'] = 'Il est nécessaire de donner un titre à la nouvelle publication';
$lang['publication']['no_resume'] = 'Il est nécessaire d\'établir un resumé de la publication';
$lang['publication']['no_level'] = 'La publication doit être rattachée à un niveau';
$lang['publication']['no_scale'] = 'La publication doit être rattachée à une échelle';
$lang['publication']['no_author'] = 'Il est impératif de nommer un rédacteur de publication';
$lang['publication']['author_not_valid'] = 'Le rédacteur choisi n\'existe pas ou son orthographe est erronée';
$lang['publication']['author_not_rights'] = 'Le rédacteur choisi n\'a pas les droits nécessaires';

/*	nommage élément rubrique
 *  	*/
$lang['publication']['title']='titre';
$lang['publication']['resume']='resumé';
$lang['publication']['level']='niveau de rattachement';
$lang['publication']['scale']='échelle de rattachement';
$lang['publication']['statut']='état de publication';
$lang['publication']['comment']='commentaire';

$lang['publication']['template']='modèle de présentation';
$lang['publication']['photouri']='visuel(s) associé(s)';
$lang['publication']['visu1']='visuel n°1';
$lang['publication']['visu2']='visuel n°2';
$lang['publication']['author']='rédacteur';
$lang['publication']['published_on']='date de publication';
$lang['publication']['not_published']='non publié';

$lang['publication']['generals']='Informations générales';
$lang['publication']['parts']='Détail de la publication';
$lang['publication']['listing']='Publications';
$lang['publication']['link_res']='Liens associés';
$lang['publication']['biblio_res']='Ressources bibliographiques';
$lang['publication']['multi_res']='Ressources';
$lang['publication']['summary']='Sommaire';



/*	nommage quickbox
 *  	*/
$lang['publication']['qb_titleadd']=' derniers ajouts effectués';
$lang['publication']['qb_titlemod']=' dernières modifications effectuées';
$lang['publication']['qb_titlesup']=' dernières suppressions effectuées';
$lang['publication']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
 *  	*/

$lang['publication']['nb_total']='publications sont repertoriées dans la base de données.';
$lang['publication']['statut_filter']='Afficher par statut';
$lang['publication']['part_number']='partie ';
$lang['publication']['part_number2']='Partie ';
$lang['publication']['description']='description';
$lang['publication']['all']='Afficher la liste complete';
$lang['publication']['noresult']='Aucune publication ne correspond à ce critère de sélection ';
$lang['news']['template_1']='Texte + photo à gauche';
$lang['news']['template_2']='Texte + photo à droite';
$lang['news']['template_3']='Texte seulement';


/*	textes modules annexes
 *  	*/
$lang['publication']['add_new_part']="Ajouter une nouvelle partie";
$lang['publication']['add_new_linkres']="Associer un nouveau lien";
$lang['publication']['add_new_multires']="Associer un nouveau document numérique";
$lang['publication']['add_new_bibliores']="Associer un nouvelle référence bibliographique";

$lang['publication']['no_link']="Aucun site n'est actuellement associé";
$lang['publication']['del_link']="Supprimer le lien";
$lang['publication']['mod_link']="Modifier le lien";

$lang['publication']['no_multi']="Aucun document n'est actuellement associé";
$lang['publication']['del_multi']="Supprimer le document numérique";
$lang['publication']['mod_multi']="Modifier le document numérique";

$lang['publication']['no_biblio']="Aucune référence bibliographique n'est actuellement associée";
$lang['publication']['del_biblio']="Supprimer la référence bibliographique";
$lang['publication']['mod_biblio']="Modifier la référence bibliographique";

$lang['publication']['no_part']="Aucune partie n'est actuellement associée";
$lang['publication']['del_part']="Supprimer la partie";
$lang['publication']['mod_part']="Modifier la partie";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Pour ajouter une publication, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['publication']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['publication']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';

$lang['publication']['help_list1']='Pour afficher le détail d\'une publication, cliquez sur le titre de celui-ci';
$lang['publication']['help_list2']='Vous pouvez supprimer une publication en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_list3']='Vous pouvez modifier une publication en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les publications desirées';
$lang['publication']['help_list5']='Pour ajouter une publication, cliquez sur le lien \'ajouter une publlication\' dans la barre de titre';


$lang['publication']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['publication']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['publication']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['publication']['help_det1']='Vous pouvez modifier les informations générales de cette publication en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_det2']='Vous pouvez supprimer cette publication en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_det3']='Pour afficher les parties constituant la publication, les liens associés, documents et ressources bibliographiques, cliquer sur afficher ces informations en bas de page';
$lang['publication']['help_det4']='Pour Ajouter-Modifier-Supprimer les parties constituant la publication, les liens associés, documents et ressources bibliographiques, cliquer sur les icônes qui leur sont associées';

$lang['publication']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de cette publication, cliquer sur \'Annuler\'';


?>
